@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from typing import Optional, Dict, Any, List
+from typing import Dict, Any
 from ipfs_dict_chain.IPFSDict import IPFSDict
 from .ranking import Ranking
-from .option import HivemindOption
 
 
 class HivemindOpinion(IPFSDict):
@@ -13,30 +12,29 @@ class HivemindOpinion(IPFSDict):
     for a particular hivemind issue question.
 
     :ivar hivemind_id: The IPFS hash of the associated hivemind issue
-    :type hivemind_id: Optional[str]
+    :vartype hivemind_id: str | None
     :ivar question_index: The index of the question this opinion is for
-    :type question_index: int
+    :vartype question_index: int
     :ivar ranking: The ranking of options for this opinion
-    :type ranking: Ranking
+    :vartype ranking: Ranking
     """
 
-    def __init__(self, cid: Optional[str] = None) -> None:
+    def __init__(self, cid: str | None = None) -> None:
         """Initialize a new HivemindOpinion.
 
         :param cid: The IPFS hash of the Opinion object
-        :type cid: Optional[str]
+        :type cid: str | None
+        :return: None
         """
-        self.hivemind_id: Optional[str] = None
+        self.hivemind_id: str | None = None
         self.question_index: int = 0
         self.ranking: Ranking = Ranking()
 
         super(HivemindOpinion, self).__init__(cid=cid)
 
-    def get(self) -> Dict[str, Any]:
+    def to_dict(self) -> Dict[str, Any]:
         """Get a JSON-serializable representation of this opinion.
 
-        Overrides the get method because it contains a non-JSON-serializable object.
-
         :return: Dictionary containing the opinion data
         :rtype: Dict[str, Any]
         """
@@ -51,6 +49,7 @@ class HivemindOpinion(IPFSDict):
 
         :param question_index: The index of the question
         :type question_index: int
+        :return: None
         """
         self.question_index = question_index
 
@@ -60,10 +59,8 @@ class HivemindOpinion(IPFSDict):
         :return: Formatted string containing the opinion details
         :rtype: str
         """
-        ret = ''
-        for i, option_hash in enumerate(self.ranking.get()):
-            option = HivemindOption(cid=option_hash)
-            ret += '\n%s: %s' % (i+1, option.value)
+        ret = f'opinion info: {self.hivemind_id} question {self.question_index} -> {str(self.ranking.to_dict())}'
+
         return ret
 
     def load(self, cid: str) -> None:
@@ -74,6 +71,7 @@ class HivemindOpinion(IPFSDict):
 
         :param cid: The IPFS hash to load
         :type cid: str
+        :return: None
         """
         super(HivemindOpinion, self).load(cid=cid)
 
@@ -82,22 +80,41 @@ class HivemindOpinion(IPFSDict):
             self.ranking = Ranking()
             return
 
-        # Handle the case where ranking is a list (legacy format)
-        if isinstance(self.ranking, list):
-            ranked_choice = self.ranking
-            self.ranking = Ranking()
-            self.ranking.set_fixed(ranked_choice=ranked_choice)
-            return
-
         # ipfs will store ranking as a dict, but we need to convert it back to a Ranking() object
         if isinstance(self.ranking, dict):
             ranking_dict = self.ranking  # Store the dict temporarily
             self.ranking = Ranking()  # Create new Ranking object
-            
+
             if 'fixed' in ranking_dict:
                 self.ranking.set_fixed(ranked_choice=ranking_dict['fixed'])
             elif 'auto_high' in ranking_dict:
                 self.ranking.set_auto_high(choice=ranking_dict['auto_high'])
             elif 'auto_low' in ranking_dict:
                 self.ranking.set_auto_low(choice=ranking_dict['auto_low'])
-            # If none of the expected keys are present, ranking will remain empty
\ No newline at end of file
+
+    def __repr__(self) -> str:
+        """Return a string representation of the opinion.
+
+        :return: The IPFS CID of the opinion without the '/ipfs/' prefix
+        :rtype: str
+        """
+        return self._cid.replace('/ipfs/', '')
+
+    def save(self) -> str:
+        """Save the opinion to IPFS.
+
+        This method handles the conversion of the Ranking object into a JSON-serializable
+        dictionary before saving the opinion to IPFS.
+
+        :return: The IPFS hash of the saved opinion
+        :rtype: str
+        """
+        # Convert the ranking object to a dict before saving
+        tmp_ranking = self.ranking if self.ranking is not None else Ranking()
+        if isinstance(self.ranking, Ranking):
+            self.ranking = self.ranking.to_dict()
+        opinion_cid = super(HivemindOpinion, self).save()
+        # Restore the ranking object
+        self.ranking = tmp_ranking
+
+        return opinion_cid
