@@ -85,6 +85,17 @@ class TestHivemindIssue:
             issue.set_restrictions({'options_per_address': 0})
         assert 'options_per_address in restrictions must be a positive integer' in str(exc_info.value)
 
+    def test_set_restrictions_none(self, issue: HivemindIssue) -> None:
+        """Test setting restrictions to None"""
+        # First set some restrictions
+        restrictions = {'options_per_address': 3}
+        issue.set_restrictions(restrictions)
+        assert issue.restrictions == restrictions
+        
+        # Then set to None
+        issue.set_restrictions(None)
+        assert issue.restrictions is None
+
     def test_initialization(self):
         assert isinstance(HivemindIssue(), HivemindIssue)
 
@@ -100,7 +111,7 @@ class TestHivemindIssue:
                                       None,
                                       {},
                                       [],
-                                      42+0j,
+                                      42 + 0j,
                                       42.0])
     def test_saving_with_invalid_name_raises_exception(self, name):
         hivemind_issue = HivemindIssue()
@@ -136,7 +147,7 @@ class TestHivemindIssue:
         hivemind_issue.save()
         assert hivemind_issue.tags == tags
 
-    @pytest.mark.parametrize("answer_type", ['String', 'Bool', 'Integer', 'Float', 'Hivemind', 'Image', 'Video', 'Complex'])
+    @pytest.mark.parametrize("answer_type", ['String', 'Bool', 'Integer', 'Float', 'Hivemind', 'File', 'Complex'])
     def test_setting_a_valid_answer_type(self, answer_type):
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = 'Test'
@@ -220,8 +231,8 @@ class TestHivemindIssue:
         hivemind_issue.set_restrictions(restrictions=restrictions)
         assert hivemind_issue.restrictions == restrictions
 
-    def test_info_method(self):
-        """Test the info() method output format"""
+    def test_issue_properties(self):
+        """Test the HivemindIssue properties"""
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test Issue"
         hivemind_issue.description = "Test Description"
@@ -230,23 +241,23 @@ class TestHivemindIssue:
         hivemind_issue.tags = ["tag1", "tag2"]
         hivemind_issue.answer_type = "String"
         hivemind_issue.set_constraints({"min_length": 5, "max_length": 10})
-        
-        info_text = hivemind_issue.info()
-        assert "Hivemind name: Test Issue" in info_text
-        assert "Hivemind description: Test Description" in info_text
-        assert "Hivemind question 1: Main Question?" in info_text
-        assert "Hivemind question 2: Follow-up Question?" in info_text
-        assert "Hivemind tags: ['tag1', 'tag2']" in info_text
-        assert "Answer type: String" in info_text
-        assert "Constraint min_length: 5" in info_text
-        assert "Constraint max_length: 10" in info_text
+
+        # Test properties directly instead of using info() method
+        assert hivemind_issue.name == "Test Issue"
+        assert hivemind_issue.description == "Test Description"
+        assert hivemind_issue.questions[0] == "Main Question?"
+        assert hivemind_issue.questions[1] == "Follow-up Question?"
+        assert hivemind_issue.tags == ["tag1", "tag2"]
+        assert hivemind_issue.answer_type == "String"
+        assert hivemind_issue.constraints["min_length"] == 5
+        assert hivemind_issue.constraints["max_length"] == 10
 
     def test_valid_description_length(self):
         """Test validation of description length"""
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
         hivemind_issue.add_question("Question?")
-        hivemind_issue.description = "a" * 256  # Too long
+        hivemind_issue.description = "a" * 5001  # Too long
         with pytest.raises(Exception) as exc_info:
             hivemind_issue.valid()
         assert "Invalid description" in str(exc_info.value)
@@ -256,13 +267,13 @@ class TestHivemindIssue:
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
         hivemind_issue.add_question("Question?")
-        
+
         # Test tag with space
         hivemind_issue.tags = ["invalid tag"]
         with pytest.raises(Exception) as exc_info:
             hivemind_issue.valid()
         assert "Invalid tags" in str(exc_info.value)
-        
+
         # Test duplicate tags
         hivemind_issue.tags = ["tag1", "tag1"]
         with pytest.raises(Exception) as exc_info:
@@ -273,13 +284,13 @@ class TestHivemindIssue:
         """Test validation of question format"""
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
-        
+
         # Test empty question
         hivemind_issue.questions = [""]
         with pytest.raises(Exception) as exc_info:
             hivemind_issue.valid()
         assert "Invalid questions" in str(exc_info.value)
-        
+
         # Test too long question
         hivemind_issue.questions = ["a" * 256]
         with pytest.raises(Exception) as exc_info:
@@ -291,7 +302,7 @@ class TestHivemindIssue:
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
         hivemind_issue.add_question("Question?")
-        
+
         # Test invalid on_selection value
         hivemind_issue.on_selection = "InvalidValue"
         with pytest.raises(Exception) as exc_info:
@@ -304,12 +315,12 @@ class TestHivemindIssue:
         hivemind_issue.name = "Test"
         hivemind_issue.add_question("Question?")
         hivemind_issue.answer_type = "Bool"
-        
+
         # Test valid boolean constraints
         constraints = {"true_value": "yes", "false_value": "no"}
         hivemind_issue.set_constraints(constraints)
         assert hivemind_issue.constraints == constraints
-        
+
         # Test invalid boolean constraints
         with pytest.raises(Exception):
             hivemind_issue.set_constraints({"true_value": 1, "false_value": 0})
@@ -319,12 +330,12 @@ class TestHivemindIssue:
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
         hivemind_issue.add_question("Question?")
-        
+
         # Test valid block_height
         constraints = {"block_height": 12345}
         hivemind_issue.set_constraints(constraints)
         assert hivemind_issue.constraints == constraints
-        
+
         # Test invalid block_height
         with pytest.raises(Exception):
             hivemind_issue.set_constraints({"block_height": "12345"})
@@ -334,16 +345,16 @@ class TestHivemindIssue:
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
         hivemind_issue.add_question("Question?")
-        
+
         # Test valid addresses list
         restrictions = {"addresses": ["addr1", "addr2"]}
         hivemind_issue.set_restrictions(restrictions)
         assert hivemind_issue.restrictions == restrictions
-        
+
         # Test invalid address type
         with pytest.raises(Exception):
             hivemind_issue.set_restrictions({"addresses": [123, 456]})
-        
+
         # Test invalid addresses container
         with pytest.raises(Exception):
             hivemind_issue.set_restrictions({"addresses": "addr1,addr2"})
@@ -353,7 +364,7 @@ class TestHivemindIssue:
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
         hivemind_issue.add_question("Question?")
-        
+
         # Test invalid specs type
         with pytest.raises(Exception) as exc_info:
             hivemind_issue.set_constraints({"specs": 123})
@@ -364,7 +375,7 @@ class TestHivemindIssue:
         hivemind_issue = HivemindIssue()
         hivemind_issue.name = "Test"
         hivemind_issue.questions = []  # Empty questions list
-        
+
         with pytest.raises(Exception) as exc_info:
             hivemind_issue.valid()
         assert "There must be at least 1 question" in str(exc_info.value)
@@ -373,4 +384,39 @@ class TestHivemindIssue:
         """Test setting constraints with invalid choices type"""
         with pytest.raises(Exception) as exc_info:
             issue.set_constraints({'choices': 'not a list'})
-        assert 'Value of constraint choices must be a list' in str(exc_info.value)
\ No newline at end of file
+        assert 'Value of constraint choices must be a list' in str(exc_info.value)
+
+    def test_get_identification_cid(self) -> None:
+        """Test the get_identification_cid method"""
+        # Create and save a hivemind issue
+        hivemind_issue = HivemindIssue()
+        hivemind_issue.name = "Test Issue"
+        hivemind_issue.add_question("Test Question?")
+        issue_cid = hivemind_issue.save()
+
+        # Get identification CID for a participant
+        participant_name = "Test Participant"
+        identification_cid = hivemind_issue.get_identification_cid(participant_name)
+
+        # Verify the identification CID is not None and is a string
+        assert identification_cid is not None
+        assert isinstance(identification_cid, str)
+
+        # Load the identification data from IPFS to verify its contents
+        from ipfs_dict_chain.IPFSDict import IPFSDict
+        identification_data = IPFSDict(cid=identification_cid)
+
+        # Verify the data contains the correct hivemind_id and name
+        assert identification_data['hivemind_id'] == issue_cid.replace('/ipfs/', '')
+        assert identification_data['name'] == participant_name
+
+    def test_set_constraints_none(self, issue: HivemindIssue) -> None:
+        """Test setting constraints to None"""
+        # First set some constraints
+        constraints = {'min_length': 5, 'max_length': 10}
+        issue.set_constraints(constraints)
+        assert issue.constraints == constraints
+        
+        # Then set to None
+        issue.set_constraints(None)
+        assert issue.constraints is None
