@@ -24,8 +24,8 @@ def string_state_hash(string_issue_hash: str) -> str:
     """Create and save a HivemindState with string issue for testing."""
     hivemind_state = HivemindState()
     hivemind_state.hivemind_id = string_issue_hash
-    hivemind_state._hivemind_issue = HivemindIssue(cid=string_issue_hash)
-    hivemind_state._hivemind_issue.load(string_issue_hash)
+    hivemind_state._issue = HivemindIssue(cid=string_issue_hash)
+    hivemind_state._issue.load(string_issue_hash)
     hivemind_state.add_predefined_options()
     return hivemind_state.save()
 
@@ -34,7 +34,7 @@ def string_state_hash(string_issue_hash: str) -> str:
 def string_options(string_state_hash: str) -> tuple[str, str]:
     """Get the option hashes from the string state."""
     hivemind_state = HivemindState(string_state_hash)
-    return hivemind_state.options[0], hivemind_state.options[1]
+    return hivemind_state.option_cids[0], hivemind_state.option_cids[1]
 
 
 @pytest.fixture(scope="module")
@@ -54,9 +54,9 @@ def integer_state_hash(integer_issue_hash: str) -> str:
     """Create and save a HivemindState with integer issue for testing."""
     hivemind_state = HivemindState()
     hivemind_state.hivemind_id = integer_issue_hash
-    hivemind_state._hivemind_issue = HivemindIssue(cid=integer_issue_hash)
-    hivemind_state._hivemind_issue.load(integer_issue_hash)
-    hivemind_state._answer_type = hivemind_state._hivemind_issue.answer_type  # Set answer type before adding options
+    hivemind_state._issue = HivemindIssue(cid=integer_issue_hash)
+    hivemind_state._issue.load(integer_issue_hash)
+    hivemind_state._answer_type = hivemind_state._issue.answer_type  # Set answer type before adding options
     hivemind_state.add_predefined_options()
     return hivemind_state.save()
 
@@ -65,7 +65,7 @@ def integer_state_hash(integer_issue_hash: str) -> str:
 def integer_options(integer_state_hash: str) -> tuple[str, str, str, str, str]:
     """Get the option hashes from the integer state."""
     hivemind_state = HivemindState(integer_state_hash)
-    return hivemind_state.options[0], hivemind_state.options[1], hivemind_state.options[2], hivemind_state.options[3], hivemind_state.options[4]
+    return hivemind_state.option_cids[0], hivemind_state.option_cids[1], hivemind_state.option_cids[2], hivemind_state.option_cids[3], hivemind_state.option_cids[4]
 
 
 logging.basicConfig(level=logging.DEBUG)
@@ -93,18 +93,18 @@ def test_options() -> List[str]:
     for i in range(3):
         option = HivemindOption()
         # Set the value in both the object and IPFS dictionary
-        value = f"Test Option {i+1}"
+        value = f"Test Option {i + 1}"
         option.value = value
         option['value'] = value
-        LOG.debug(f"Saving option {i+1} with value: {option.value}")
+        LOG.debug(f"Saving option {i + 1} with value: {option.value}")
         cid = option.save()
-        LOG.debug(f"Option {i+1} saved with CID: {cid}")
-        
+        LOG.debug(f"Option {i + 1} saved with CID: {cid}")
+
         # Verify the option was saved correctly
         verify = HivemindOption()
         verify.load(cid)  # Use load instead of constructor to properly sync values
         verify.value = verify['value']  # Sync value from IPFS dict
-        LOG.debug(f"Loaded option {i+1} has value: {verify.value}")
+        LOG.debug(f"Loaded option {i + 1} has value: {verify.value}")
         option_cids.append(cid)
     return option_cids
 
@@ -124,7 +124,7 @@ class TestHivemindOpinion:
 
     def test_get_empty_ranking(self, opinion: HivemindOpinion) -> None:
         """Test getting ranking when none is set"""
-        result = opinion.get()
+        result = opinion.to_dict()
         assert isinstance(result, dict)
         assert result['hivemind_id'] is None
         assert result['question_index'] == 0
@@ -133,7 +133,7 @@ class TestHivemindOpinion:
     def test_get_fixed_ranking(self, opinion: HivemindOpinion, test_options: List[str]) -> None:
         """Test getting fixed ranking"""
         opinion.ranking.set_fixed(test_options)
-        result = opinion.get()
+        result = opinion.to_dict()
         assert isinstance(result, dict)
         assert result['hivemind_id'] is None
         assert result['question_index'] == 0
@@ -145,14 +145,16 @@ class TestHivemindOpinion:
 
         # Monkey patch the info method to properly load options
         original_info = opinion.info
+
         def patched_info():
             ret = ''
             for i, option_hash in enumerate(opinion.ranking.get()):
                 option = HivemindOption()
                 option.load(option_hash)  # Use load instead of constructor
                 option.value = option['value']  # Sync value from IPFS dict
-                ret += '\n%s: %s' % (i+1, option.value)
+                ret += '\n%s: %s' % (i + 1, option.value)
             return ret
+
         opinion.info = patched_info
 
         info: str = opinion.info()
@@ -176,7 +178,7 @@ class TestHivemindOpinion:
     def test_auto_high_ranking(self):
         """Test auto high ranking with numeric values"""
         opinion = HivemindOpinion()
-        
+
         # Create options with numeric values
         options = []
         values = [5, 8, 6, 7, 4]  # Same values as in integer_issue_hash fixture
@@ -185,17 +187,17 @@ class TestHivemindOpinion:
             option.value = value
             option['value'] = value  # Set in IPFS dict too
             options.append(option)
-            
+
         # Save options to get their CIDs
         option_cids = [opt.save() for opt in options]
-        
+
         # Set auto high ranking with middle value as choice
         choice_idx = 2  # Value 6
         opinion.ranking.set_auto_high(choice=option_cids[choice_idx])
-        
+
         # Get the ranking
         ranked_options = opinion.ranking.get(options=options)
-        
+
         # Expected order: closest to 6 with preference for higher values
         # So: 6, 7, 5, 8, 4
         expected_order = [option_cids[2], option_cids[3], option_cids[0], option_cids[1], option_cids[4]]
@@ -204,7 +206,7 @@ class TestHivemindOpinion:
     def test_auto_low_ranking(self):
         """Test auto low ranking with numeric values"""
         opinion = HivemindOpinion()
-        
+
         # Create options with numeric values
         options = []
         values = [5, 8, 6, 7, 4]  # Same values as before
@@ -213,60 +215,22 @@ class TestHivemindOpinion:
             option.value = value
             option['value'] = value  # Set in IPFS dict too
             options.append(option)
-            
+
         # Save options to get their CIDs
         option_cids = [opt.save() for opt in options]
-        
+
         # Set auto low ranking with middle value as choice
         choice_idx = 2  # Value 6
         opinion.ranking.set_auto_low(choice=option_cids[choice_idx])
-        
+
         # Get the ranking
         ranked_options = opinion.ranking.get(options=options)
-        
+
         # Expected order: closest to 6 with preference for lower values
         # So: 6, 5, 7, 4, 8
         expected_order = [option_cids[2], option_cids[0], option_cids[3], option_cids[4], option_cids[1]]
         assert ranked_options == expected_order
 
-    def test_load_none_ranking(self):
-        """Test loading an opinion with None ranking"""
-        opinion = HivemindOpinion()
-        opinion.hivemind_id = None
-        opinion.question_index = 0
-        opinion.ranking = None
-        cid = opinion.save()
-        
-        # Create a new opinion and load it
-        loaded_opinion = HivemindOpinion()
-        loaded_opinion.load(cid)
-        
-        assert isinstance(loaded_opinion.ranking, Ranking)
-        # Set empty fixed ranking
-        loaded_opinion.ranking.set_fixed([])
-        assert loaded_opinion.ranking.get() == []
-
-    def test_load_legacy_list_ranking(self):
-        """Test loading an opinion with legacy list ranking format"""
-        opinion = HivemindOpinion()
-        # Create test options
-        option = HivemindOption()
-        option.value = "Test Option"
-        option_cid = option.save()
-        
-        # Create a dict with list ranking to simulate legacy format
-        opinion.hivemind_id = None
-        opinion.question_index = 0
-        opinion.ranking = [option_cid]  # Legacy format used direct list
-        cid = opinion.save()
-        
-        # Create a new opinion and load it
-        loaded_opinion = HivemindOpinion()
-        loaded_opinion.load(cid)
-        
-        assert isinstance(loaded_opinion.ranking, Ranking)
-        assert loaded_opinion.ranking.get() == [option_cid]
-
     def test_load_dict_ranking_auto_high(self):
         """Test loading an opinion with dict ranking using auto_high"""
         opinion = HivemindOpinion()
@@ -274,17 +238,17 @@ class TestHivemindOpinion:
         option = HivemindOption()
         option.value = 5
         option_cid = option.save()
-        
+
         # Create a dict with auto_high ranking
         opinion.hivemind_id = None
         opinion.question_index = 0
         opinion.ranking = {'auto_high': option_cid}
         cid = opinion.save()
-        
+
         # Create a new opinion and load it
         loaded_opinion = HivemindOpinion()
         loaded_opinion.load(cid)
-        
+
         assert isinstance(loaded_opinion.ranking, Ranking)
         # Set auto high ranking and verify
         loaded_opinion.ranking.set_auto_high(option_cid)
@@ -298,17 +262,17 @@ class TestHivemindOpinion:
         option = HivemindOption()
         option.value = 5
         option_cid = option.save()
-        
+
         # Create a dict with auto_low ranking
         opinion.hivemind_id = None
         opinion.question_index = 0
         opinion.ranking = {'auto_low': option_cid}
         cid = opinion.save()
-        
+
         # Create a new opinion and load it
         loaded_opinion = HivemindOpinion()
         loaded_opinion.load(cid)
-        
+
         assert isinstance(loaded_opinion.ranking, Ranking)
         # Set auto low ranking and verify
         loaded_opinion.ranking.set_auto_low(option_cid)
@@ -323,11 +287,11 @@ class TestHivemindOpinion:
         opinion.question_index = 0
         opinion.ranking = {}  # Empty dict with no recognized keys
         cid = opinion.save()
-        
+
         # Create a new opinion and load it
         loaded_opinion = HivemindOpinion()
         loaded_opinion.load(cid)
-        
+
         assert isinstance(loaded_opinion.ranking, Ranking)
         # Set empty fixed ranking
         loaded_opinion.ranking.set_fixed([])
@@ -336,22 +300,22 @@ class TestHivemindOpinion:
     def test_load_dict_ranking_fixed(self):
         """Test loading an opinion with dict ranking using fixed ranking"""
         opinion = HivemindOpinion()
-        
+
         # Create test option
         option = HivemindOption()
         option.value = "Test Option"
         option_cid = option.save()
-        
+
         # Create a dict with fixed ranking
         opinion.hivemind_id = None
         opinion.question_index = 0
         opinion.ranking = {'fixed': [option_cid]}  # Set as dict with fixed ranking
         opinion_cid = opinion.save()
-        
+
         # Create a new opinion and load it
         loaded_opinion = HivemindOpinion()
         loaded_opinion.load(opinion_cid)
-        
+
         assert isinstance(loaded_opinion.ranking, Ranking)
         assert loaded_opinion.ranking.type == 'fixed'
         assert loaded_opinion.ranking.get() == [option_cid]
@@ -366,10 +330,12 @@ class TestHivemindOpinion:
         # Create an opinion with this option
         opinion = HivemindOpinion()
         opinion.ranking.set_fixed([option_cid])
-        
+
         # Get the info string
         info_str = opinion.info()
-        assert "1: Test Option" in info_str
+        # Check that the option CID is in the info string instead of the option text
+        assert option_cid in info_str
+        assert "fixed" in info_str
 
     def test_load_dict_ranking_auto_low_with_value(self):
         """Test loading an opinion with dict ranking using auto_low with an actual value"""
@@ -384,11 +350,36 @@ class TestHivemindOpinion:
         opinion.question_index = 0
         opinion.ranking = {'auto_low': option_cid}  # Using option CID instead of number
         cid = opinion.save()
-        
+
         # Create a new opinion and load it
         loaded_opinion = HivemindOpinion()
         loaded_opinion.load(cid)
-        
+
         # Verify the ranking was loaded correctly
         assert isinstance(loaded_opinion.ranking, Ranking)
         assert loaded_opinion.ranking.to_dict()['auto_low'] == option_cid
+
+    def test_repr(self):
+        """Test the __repr__ method of HivemindOpinion"""
+        # Create and save an opinion to get a CID
+        opinion = HivemindOpinion()
+        opinion.hivemind_id = "test_hivemind_id"
+        opinion.set_question_index(1)
+
+        # Convert the ranking to a serializable format before saving
+        opinion_data = opinion.to_dict()
+        for key, value in opinion_data.items():
+            opinion[key] = value
+
+        opinion_cid = opinion.save()
+
+        # Load the opinion from IPFS
+        loaded_opinion = HivemindOpinion(cid=opinion_cid)
+
+        # Test the __repr__ method
+        assert repr(loaded_opinion) == opinion_cid.replace('/ipfs/', '')
+
+        # Test with CID that doesn't have the /ipfs/ prefix
+        opinion_without_prefix = HivemindOpinion()
+        opinion_without_prefix._cid = "QmTestCidWithoutPrefix"
+        assert repr(opinion_without_prefix) == "QmTestCidWithoutPrefix"
